<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he_IL">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="26"/>
        <location filename="ui_mainwindow.h" line="756"/>
        <source>Network Assistant</source>
        <translation>מסייע הרשת</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <location filename="ui_mainwindow.h" line="799"/>
        <source>About...</source>
        <translation>על אודות…</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <location filename="ui_mainwindow.h" line="803"/>
        <source>Help</source>
        <translation>עזרה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <location filename="ui_mainwindow.h" line="805"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="184"/>
        <location filename="ui_mainwindow.h" line="807"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="ui_mainwindow.h" line="770"/>
        <source>Status</source>
        <translation>מצב</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <location filename="ui_mainwindow.h" line="757"/>
        <source>IP address</source>
        <translation>כתובת IP</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="261"/>
        <location filename="ui_mainwindow.h" line="760"/>
        <source>Hardware detected</source>
        <translation>זוהתה חומרה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Enable</source>
        <translation>הפעלה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="303"/>
        <location filename="mainwindow.ui" line="593"/>
        <location filename="mainwindow.ui" line="706"/>
        <location filename="ui_mainwindow.h" line="761"/>
        <location filename="ui_mainwindow.h" line="774"/>
        <location filename="ui_mainwindow.h" line="780"/>
        <source>Re-scan</source>
        <translation>סריקה מחדש</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Enabled</source>
        <translation>פעיל</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="377"/>
        <source>Interface</source>
        <translation>מנשק</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="382"/>
        <source>Driver</source>
        <translation>מנהל התק</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="387"/>
        <source>Description</source>
        <translation>תיאור</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="392"/>
        <source>Vendor</source>
        <translation>יצרן</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="397"/>
        <source>Product</source>
        <translation>מוצר</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="405"/>
        <source>Disable</source>
        <translation>השבתה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="419"/>
        <location filename="ui_mainwindow.h" line="762"/>
        <source>Active interface</source>
        <translation>מנשק פעיל</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="435"/>
        <location filename="ui_mainwindow.h" line="764"/>
        <source>WiFi status</source>
        <translation>מצב רשת אלחוטית</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <location filename="ui_mainwindow.h" line="767"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>משחררת את החסימות הרכות/קשות של ההתקנים האלחוטיים</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <location filename="ui_mainwindow.h" line="769"/>
        <source>Unblock WiFi Devices</source>
        <translation>שחרור התקני רשת אלחוטית</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="492"/>
        <location filename="ui_mainwindow.h" line="776"/>
        <source>Linux drivers</source>
        <translation>מנהלי התקנים של לינוקס</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="504"/>
        <location filename="ui_mainwindow.h" line="771"/>
        <source>Associated Linux drivers</source>
        <translation>מנהלי התקנים משויכים של לינוקס</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="513"/>
        <location filename="ui_mainwindow.h" line="772"/>
        <source>Load Driver</source>
        <translation>טעינת מנהל התקן</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <location filename="ui_mainwindow.h" line="773"/>
        <source>Unload Driver</source>
        <translation>פריקת מנהל התקן</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <location filename="mainwindow.cpp" line="833"/>
        <location filename="ui_mainwindow.h" line="775"/>
        <source>Block Driver</source>
        <translation>חסימת מנהל התקן</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="632"/>
        <location filename="ui_mainwindow.h" line="785"/>
        <source>Windows drivers</source>
        <translation>מנהלי התקנים ל־Windows</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="638"/>
        <location filename="ui_mainwindow.h" line="777"/>
        <source>Available Windows drivers</source>
        <translation>מנהלי התקנים זמינים ל־Windows</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="672"/>
        <location filename="ui_mainwindow.h" line="778"/>
        <source>Remove Driver</source>
        <translation>הסרת מנהל התקן</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="683"/>
        <location filename="ui_mainwindow.h" line="779"/>
        <source>Add Driver</source>
        <translation>הוספת מנהל התקן</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <location filename="ui_mainwindow.h" line="781"/>
        <source>About NDISwrapper</source>
        <translation>על NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <location filename="ui_mainwindow.h" line="782"/>
        <source>Install NDISwrapper</source>
        <translation>התקנת NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <location filename="ui_mainwindow.h" line="783"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>כדי להשתמש במנהלי התקנים שיועדו ל־Windows עליך להתקין את NDISwrapper תחילה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <location filename="ui_mainwindow.h" line="784"/>
        <source>Uninstall NDISwrapper</source>
        <translation>הסרת NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="795"/>
        <location filename="ui_mainwindow.h" line="798"/>
        <source>Net diagnostics</source>
        <translation>ניתוח הרשת</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="807"/>
        <location filename="ui_mainwindow.h" line="786"/>
        <source>Ping</source>
        <translation>פינג</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="813"/>
        <location filename="mainwindow.ui" line="933"/>
        <location filename="ui_mainwindow.h" line="787"/>
        <location filename="ui_mainwindow.h" line="793"/>
        <source>Target URL:</source>
        <translation>כתובת יעד:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="823"/>
        <location filename="ui_mainwindow.h" line="788"/>
        <source>Packets</source>
        <translation>מנות נתונים</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="868"/>
        <location filename="mainwindow.ui" line="991"/>
        <location filename="ui_mainwindow.h" line="789"/>
        <location filename="ui_mainwindow.h" line="795"/>
        <source>Start</source>
        <translation>התחלה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="885"/>
        <location filename="mainwindow.ui" line="1008"/>
        <location filename="ui_mainwindow.h" line="790"/>
        <location filename="ui_mainwindow.h" line="796"/>
        <source>Clear</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="899"/>
        <location filename="mainwindow.ui" line="1022"/>
        <location filename="ui_mainwindow.h" line="791"/>
        <location filename="ui_mainwindow.h" line="797"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="927"/>
        <location filename="ui_mainwindow.h" line="792"/>
        <source>Traceroute</source>
        <translation>מעקב נתיב</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="943"/>
        <location filename="ui_mainwindow.h" line="794"/>
        <source>Hops</source>
        <translation>נק׳ אמצע</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>כתובת ה־IP מהנתב:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>כתובת IP חיצונית:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>מנשק: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>מנהל התקן: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="125"/>
        <location filename="mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>תיאור: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>מוצר: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>יצרן: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="127"/>
        <location filename="mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>פעיל: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="195"/>
        <location filename="mainwindow.cpp" line="209"/>
        <location filename="mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>ה&amp;עתקה</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <location filename="mainwindow.cpp" line="211"/>
        <location filename="mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="198"/>
        <location filename="mainwindow.cpp" line="212"/>
        <location filename="mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>העתקה של ה&amp;כול</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="200"/>
        <location filename="mainwindow.cpp" line="214"/>
        <location filename="mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="260"/>
        <location filename="mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute (מעקב נתיב) לא מותקן</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Traceroute (מעקב נתיב) לא מותקן, להתקין אותו כעת?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroute (מעקב נתיב) לא הותקן</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>לא ניתן להתקין את Traceroute (מעקב נתיב). יתכן שזה קורה כיוון שזאת הפעלה מתקליטור חי או שאין לך גישה למאגרי התכנה.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute (מעקב נתיב) אינו מותקן ולא זוהה חיבור לאינטרנט ולכן גם לא ניתן להתקין אותו</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>אין מארח יעד</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>נא למלא את שדה מארח היעד</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>מנהלי התקנים שנטענו</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>מנהלי התקנים שלא נטענו</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>מנהלי התקנים חסומים</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>מנהלי התקנים חסומים של Broadcom</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ndiswrapper לא מותקן</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>מנהל ההתקן הותקן</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation>ובשימוש של</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>. מנהל התקן חלופי: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>מנהל ההתקן הוסר מרשימת החסימה</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>מנהל ההתקן הוסר מרשימת החסימה.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>המודול נחסם</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>ההתקנה הצליחה</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>זוהתה שגיאה, לא ניתן להדר את מנהל ההתקן עם ndiswrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>זוהתה שגיאה, לא ניתן להתקין את ndiswrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>אירעה שגיאה בעת הסרת Ndiswrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>שחרור חסימת מנהל התקן</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>מופעל</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>מושבת</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>בורר החומרה של הרשת האלחוטית כבוי</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>נא לאתר את מנהל ההתקן של Windows שברצונך להוסיף</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>קובץ פרטי התקנה של Windows‏ (‎*.inf)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>לא נמצא קובץ ‎*.sys</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>קובצי ה־‎*.sys חייבים להיות באותו המקום יחד עם קובץ ה־‎*.inf. לא ניתן למצוא את %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>ההפניה לקובץ ה־sys לא נמצאה</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>לא ניתן להגדיר מה הוא קובץ ה־sys עבור מנהל ההתקן הנתון לאחר פענוח קובץ ה־inf</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>מנהל ההתקן עם Ndiswrapper הוסר.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>עזרה עבור %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>לא ניתן לשחרר התקנים.
התקני הרשת האלחוטית כנראה כבר משוחררים.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>התקני הרשת האלחוטית שוחררו.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>על אודות %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>גירסה:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for antiX Linux</source>
        <translation>תכנית לפתרון תקלות ולהגדרת רשת עבור antiX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>זכויות היוצרים (c) שמורות ל־MEPIS LLC ול־MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>רישיון %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>מנהל ההתקן נטען</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>מנהל ההתקן נפרק</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="about.cpp" line="52"/>
        <source>License</source>
        <translation>רישיון</translation>
    </message>
    <message>
        <location filename="about.cpp" line="53"/>
        <location filename="about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>יומן שינויים</translation>
    </message>
    <message>
        <location filename="about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <location filename="main.cpp" line="70"/>
        <location filename="main.cpp" line="78"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>כנראה שנכנסת למערכת בתור משתמש על (root), נא לצאת ולהיכנס כמשתמש רגיל כדי להשתמש בתוכנית הזאת.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>לא ניתן לטעון</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>לא ניתן לפרוק</translation>
    </message>
</context>
</TS>